The Font Awesome Community
Author: Dave Gandy
Description: Font Awesome, the iconic font designed for Bootstrap

# Community

Lots of ways to get involved with Font Awesome

- Follow @fontawesome
- Tweet

Heads up! These docs are for v3.2.1, which is no longer officially supported. Check out the latest version of Font Awesome!

Font Awesome has a vibrant community of folks helping each other out. You can get support, report bugs, request new icons, submit pull requests, and check upcoming milestones.

## Getting Support

Having trouble getting Font Awesome up and running? Something not working the way you think it should? I hate that I don't have time to answer Font Awesome support emails anymore. So here are some things you might wanna do:

1. Make sure you've read the latest version of how to get started. It's been updated recently to make Font Awesome even easier to use.
2. Check out the existing questions tagged as Font Awesome over on Stack Overflow. Other folks might have had the same question you've had.
3. Can't find the answer to your question on Stack Overflow? Ask a new question, then send me an email and I might be able to take a look.

## Reporting Bugs

Found a problem with Font Awesome? Feel free to submit an issue on the GitHub project. But please keep the following in mind:

1. Please be nice. Font Awesome is a happy place.
2. Please search to see if your icon request already exists.
3. Before opening any issue, please read the generic issue guidelines, by Nicolas Gallagher.
4. After doing everything above, feel free to submit an issue.

## Requesting New Icons

New icons mostly start as requests by the Font Awesome community on GitHub. Want to request a new icon? Here are some things to keep in mind:

1. Please be nice. Font Awesome is a happy place.
2. Please search to see if your icon request already exists.
3. Please and thank you if you include the following:
   - Title your new issue `Icon request: icon-name`.
   - Include a few use cases for your requested icon. How do you plan on using it?
   - Attach a single color image or two that represent the idea you're going for.
4. Concrete objects make good icons, since abstract concepts are, well, abstract. It's harder to make an icon to represent happiness. It's easier to make a smiley face.

## Submitting Pull Requests

Found a way to solve a bug in Font Awesome? Want to contribute new features? Here are a few things to remember:

1. Please submit all pull requests against *-wip branches.
2. All pull requests submitted against master will be summarily closed and this guide referenced.
3. After doing everything above, feel free to submit a pull request.

## Project Milestones

Want to keep up with what's planned for Font Awesome? Check out our milestones on the GitHub project.

## Thanks To

Thanks to @robmadole and @supercodepoet for icon design review, advice, some Jekyll help, and being all around badass coders.

Thanks to @grantgordon and @johnsmclay for developing and hosting icnfnt, the best way to subset Font Awesome.

Thanks to MaxCDN for providing the excellent BootstrapCDN, the fastest and easiest way to get started with Font Awesome.

## Tell Me Thanks

Hopefully you think Font Awesome is awesome. I've put hundreds of hours into the project to give back to the open source community. If you'd like, here are a couple of ways you can tell me thanks for all my hard work.

### Tip me on Gittip

Gittip is a great way to let developers know you appreciate their work.

### My Amazon Wish List

Or pick something straight from my wish list. Gift cards are great.